'******************************************************************************
'*  io.spin - handle input and output requests sent by pm80
'*
'*  (c) Juergen Buchmueller <pullmoll@t-online.de>
'*
'* $Id: io.spin,v 1.5 2010-06-05 14:42:47 pm Exp $
'******************************************************************************
CON

	io_cmd_out		=	$01		' I/O emulator command output
	io_cmd_in		=	$02		' I/O emulator command input
	io_cmd_break		=	$03		' I/O emulator command break
	io_cmd_kbd		=	$04		' I/O emulator command read TRS-80 keyboard

	p0_kbd_clock		=	%00000001	' port 0 keyboard clock counter
	p0_kbd_reset		=	%00000010	' port 0 keyboard reset counter
	p0_unused_2		=	%00000100
	p0_single_step		=	%00001000	' single step CPU
	p0_tape_led		=	%00010000	' tape drive LED
	p0_unused_5		=	%00100000

	p2_unused_0		=	%00000001
	p2_overrun_err		=	%00000010
	p2_parity_err		=	%00000100
	p2_framing_err		=	%00001000
	p2_unused_4		=	%00010000
	p2_unused_5		=	%00100000
	p2_tbr_empty		=	%01000000
	p2_rbr_full		=	%10000000

	SCRATCH_RAM		=	$1000

	baud			=	2400		' baud rate

	FSEL_TOP		=	1
	FSEL_H			=	14

VAR
	long	cog
	long	io_command
	long	params[2]
	long	rc
	word	runaddr
	word	badr
	word	bmin
	word	bmax
	word	bcnt
	word	topy
	word	boty
	word	ndir
	word	row
	word	y0
	word	speed
	byte	csum
	byte	key
	byte	curx
	byte	cury
	byte	getdir
	byte	de[32]					' directory entry
	byte	name[12+1]
	byte	datetime[20+1]
	byte	buff[64]

OBJ
	fat	: "fatfs"
	kbd	: "keyboard"
#ifdef TV
	vid	: "video"
#endif TV
#ifdef VGA
	vid	: "vga"
#endif VGA
	sio	: "pcFullDuplexSerial2FC"

PUB start(pins) : okay | i
	stop

	videoram_ptr := @videoram
	chr(12)
	gotoxy(0,15)
	str(string("* Nascom emulator on the Parallax Propeller *",13,10))

	' ***************************************************************
	' Start the FAT driver and the SD SPI object (must be first)
	'
	okay := \fat.start(byte[pins][4], byte[pins][5], byte[pins][6], byte[pins][7])
	if okay < 0
		failure(string("FAT + SD SPI"),okay)
	else
		success(string("FAT + SD SPI"))
	spi_command := fat.get_SPI_command
	spi_blocknr := spi_command + 4
	spi_address := spi_command + 8
	iobuff_ptr := \fat.get_memory

#ifdef TV
	' ***************************************************************
	' Start the Nascom TV video object
	'
	params[0] := @videoram				' 1K video RAM
	params[1] := byte[pins][11]			' video pin
	okay := \vid.start(@params)
	if okay =< 0
		failure(string("TV"),okay)
		return
	success(string("TV"))
#endif
#ifdef VGA
	' ***************************************************************
	' Start the Nascom VGA video object
	'
	params[1] := byte[pins][11]			' video pin
	okay := \vid.start(byte[pins][11], @videoram, @sync)
	if okay <> 1
		failure(string("VGA"),okay)
		return
	success(string("VGA"))
#endif

	' ***************************************************************
	' Start the Nascom keyboard driver
	'
	okay := \kbd.startx(byte[pins][8], byte[pins][9], 0, 40)
	if okay < 0
		failure(string("KBD"),okay)
		return
	kbd_states := kbd.states_ptr
	success(string("KBD"))

	' ***************************************************************
	' Start the SIO driver
	'

	sio.AddPort(0, byte[pins][0], byte[pins][1], -1, -1, sio#DEFAULTTHRESHOLD, sio#NOMODE, baud)
	if byte[pins][2] <> $ff
		sio.AddPort(1, byte[pins][2], byte[pins][3], -1, -1, sio#DEFAULTTHRESHOLD, sio#NOMODE, baud)
	okay := \sio.Start
	if okay =< 0
		failure(string("SIO"),okay)
		return
	success(string("SIO"))
	tx_head0 := sio.get_tx_head
	tx_tail0 := sio.get_tx_tail
	tx_buffer0 := sio.get_tx_buffer
	rx_head0 := sio.get_rx_head
	rx_tail0 := sio.get_rx_tail
	rx_buffer0 := sio.get_rx_buffer

	longfill(iobuff_ptr, 0, 512/4)
	repeat i from 0 to 512*1023 step 512
		fat.write_xmm_ram(iobuff_ptr, i, 512)

	' ***************************************************************
	' mount the FAT, i.e. check the format of the SD media
	'
	okay := \fat.mount(0)
	if okay < 0
		failure(string("FAT mount"), okay)
		return -1
	str(string("FAT type is FAT"))
	dec(fat.get_type)
	crlf

	rom_load

	' *********************************************************
	' file selection
	'
	waitcnt(CNT + 2*clkfreq)
	getdir := 1
	repeat y0 from FSEL_TOP - 1 to FSEL_TOP + FSEL_H - 1
		gotoxy(0, y0)
		chr(22)
	repeat while getdir
		gotoxy(0, FSEL_TOP - 1)
		str(string("Sorting directory...",22))
		readdir
		row := 0
		topy := 0
		gotoxy(0, FSEL_TOP - 1)
		str(string("Select a file to load ("))
		dec(boty)
		chr("/")
		dec(ndir)
		str(string("):", 22))
		speed := 10
		repeat
			repeat y0 from 0 to FSEL_H - 1
				rc := direntry_name(topy + y0, @buff)
				if rc < 0
					buff[0] := " "
					buff[1] := " "
					buff[2] := 0
				gotoxy(0, FSEL_TOP+y0)
				if y0 == row
					str(string("=> "))
				else
					str(string("   "))
				str(@buff)
				if y0 == row
					str(string(" <="))
				chr(22)

			waitcnt(CNT + clkfreq / speed)

			if kbd.keystate(3*8+6)	' Down arrow
				if key == 3*8+6
					speed := ++speed <# 30
				else
					speed := 10
					key := 3*8+6
				if (row < FSEL_H - 1) and (row < boty)
					row++
				elseif topy < boty - (FSEL_H - 1)
					topy++
			elseif key == 3*8+6
				key := 0

			if kbd.keystate(1*8+6)	' Up arrow
				if key == 1*8+6
					speed := ++speed <# 30
				else
					speed := 10
					key := 1*8+6
				if row > 0
					row--
				elseif topy > 0
					topy--
			elseif key == 1*8+6
				key := 0

			if kbd.keystate(9*8+6)	' Page down
				key := 9*8+6
				if topy + FSEL_H + FSEL_H - 1 < boty
					topy += FSEL_H
				else
					topy := boty - (FSEL_H - 1)
					row := boty - topy

			if kbd.keystate(8*8+6)	' Page up
				key := 8*8+6
				if topy - FSEL_H > 0
					topy -= FSEL_H
				else
					topy := 0
					row := 0

			if kbd.keystate(1)	' Return
				repeat y0 from 0 to FSEL_H - 1
					gotoxy(0, FSEL_TOP+y0)
					chr(22)
				gotoxy(0, FSEL_TOP)
				rc := direntry_name(topy + row, @buff)
				getdir := 0
				if byte[@buff][0] == "<"
					chdir_entry(topy + row)
					getdir := 1
					quit
				elseif nas_load(@buff) == 0
					quit
		

	' ***************************************************************
	' Start the I/O handler cog
	'
	dira_mask := 1 << byte[pins][10]		' set audio pin mask
	ctra_mode := %00110 << 26 | byte[pins][10]	' set to single ended DUTY mode
	okay := cog := COGNEW(@entry, @io_command) + 1
	if okay =< 0
		failure(string("I/O"),okay)
		return -1
	success(string("I/O"))

	str(string("Press <RETURN> to start ",13,10))
	repeat until !kbd.keystate(1)
	repeat until kbd.keystate(1)
	repeat until !kbd.keystate(1)

	return 0

PUB stop
'' Stop CPU simulator - frees a cog
	if cog
		cogstop(cog~ - 1)

PUB command_addr
'' Return the address of the command long
	return @io_command

PUB get_videoram
'' Return the address of the video RAM
	return @videoram

PRI gotoxy(x,y)
	curx := (x #> 0) <# 47
	cury := (y #> 0) <# 15

PRI chr(ch)
	case ch
		22:	' clear to end of line
			bytefill(videoram_ptr + cury << 6 + curx + 10, $20, 48 - curx)
		13:	' carriage return
			curx := 0
		12:	' form feed - clear screen
			wordfill(videoram_ptr, $20202020, 64*16/2)
			curx := 0
			cury := 0
		10:	' line feed
			cury += 1
			if cury > 14
				wordmove(videoram_ptr, videoram_ptr + 64, 64*14/2)
				wordfill(videoram_ptr + 64*14 + 10, $2020, 48/2)
				cury := 14
		9:	' tab
			repeat until (curx & 7) == 0
				chr(32)
		8:	' back space
			if curx > 0
				--curx
		other:
			byte[videoram_ptr][cury << 6 + curx + 10] := ch
			curx++
			if curx == 48
				chr(13)
				chr(10)

PRI str(src) | i
	repeat i from 0 to strsize(src) - 1
		chr(byte[src][i])

PRI dec(value) | _i
'' Print a decimal number
	result := 0
	if value < 0
		chr("-")
		if (value == NEGX)
			chr("2")
			value += 2_000_000_000
		-value
	_i := 1_000_000_000
	repeat 10
		if value => _i
			chr(value / _i + "0")
			value //= _i
			result~~
		elseif result or _i == 1
			chr("0")
		_i /= 10

PRI crlf
	chr(13)
	chr(10)

PRI dec_size(value)
	if value > 1048576
		dec(value/1048576)
		chr(".")
		dec(10*(value // 1048576) / 1048576)
		str(string("MB"))
	elseif value > 1024
		dec(value/1024)
		chr(".")
		dec(10*(value // 1024) / 1024)
		str(string("KB"))
	else
		dec(value)

PRI hex(value, digits)
'' Print a hexadecimal number

	value <<= (8 - digits) << 2
	repeat digits
		chr(lookupz((value <-= 4) & $F : "0".."9", "A".."F"))

PRI bin(value, digits)
'' Print a binary number

	value <<= 32 - digits
	repeat digits
		chr((value <-= 1) & 1 + "0")

PRI chr_ptr(ch, dst)
	byte[dst++] := ch
	byte[dst] := 0
	return dst

PRI str_ptr(src, dst) | i
	repeat i from 0 to strsize(src) - 1
		byte[dst++] := byte[src][i]
	byte[dst] := 0
	return dst

PRI dec_ptr(value, dst) | _i
'' Print a decimal number
	result := 0
	if value < 0
		dst := chr_ptr("-", dst)
		if (value == NEGX)
			dst := chr_ptr("2", dst)
			value += 2_000_000_000
		-value
	_i := 1_000_000_000
	repeat 10
		if value => _i
			dst := chr_ptr(value / _i + "0", dst)
			value //= _i
			result~~
		elseif result or _i == 1
			dst := chr_ptr("0", dst)
		_i /= 10
	return dst

PRI dec_size_ptr(value, dst)
	if value > 1048576
		dst := dec_ptr(value/1048576, dst)
		dst := chr_ptr(".", dst)
		dst := dec_ptr(10*(value // 1048576) / 1048576, dst)
		dst := str_ptr(string("MB"), dst)
	elseif value > 1024
		dst := dec_ptr(value/1024, dst)
		dst := chr_ptr(".", dst)
		dst := dec_ptr(10*(value // 1024) / 1024, dst)
		dst := str_ptr(string("KB"), dst)
	else
		dst := dec_ptr(value, dst)
	return dst

PRI failure(who, val)
	str(who)
	str(string(" failed: "))
	dec(val)
	crlf

PRI success(who)
	str(who)
	str(string(" initialized, "))
	dec(free_cogs)
	str(string(" cogs free.", 13, 10))

PUB free_cogs : free | i, cogs[8], jmp_0
	jmp_0 := %010111_0001_1111_000000000_000000000
	repeat while (cogs[free] := cognew(@jmp_0, 0)) => 0 
		free++
	if free
		repeat i from 0 to free - 1
			cogstop(cogs[i])
	return free

PRI strncmp(dst, src, n) | i
	repeat i from 0 to n - 1
		if byte[dst][i] <> byte[src][i]
			return byte[dst][i] - byte[src][i]
	return 0

PRI rx_insert(ch)
	byte[rx_buffer0][long[rx_head0]] := ch
	long[rx_head0] := (long[rx_head0] + 1) & 255

PRI rom_load | fp, i
	' *********************************************************
	' find the NASCOM.CHR file and load it to the chargen
	'
	fp := open_file(string("NASCOM.CHR"))
	if fp => 0
		repeat i from $0000 to $0e00 step $200
			if fat.fread(fp, iobuff_ptr, $200) == $200
				vid.write_chargen(i, iobuff_ptr, $200)
		str(string("Loaded to character generator",13,10))

	' *********************************************************
	' find the NASSYS1.ROM file and load it to 0000-07FF
	'
	fp := open_file(string("NASSYS1.ROM"))
	if fp < 0
		return -1
	repeat i from $0000 to $0600 step $200
		if fat.fread(fp, iobuff_ptr, $200) == $200
			fat.write_xmm_ram(iobuff_ptr, i, $200)

	' *********************************************************
	' find the BASIC.ROM file and load it to E000-FFFF
	'
	fp := open_file(string("BASIC.ROM"))
	if fp < 0
		return -1
	repeat i from $e000 to $fe00 step $200
		if fat.fread(fp, iobuff_ptr, $200) == $200
			fat.write_xmm_ram(iobuff_ptr, i, $200)
	return 0

PRI readdir | rec, i, swapped
	rec := fat.opendir(@de)
	boty := 0
	ndir := 0
	repeat while rec => 0
		ndir++
		if byte[@de][fat#dent_name] <> $e5	' deleted entry?
			if (fat.match(@de, string("*.NAS")) or fat.isdir(@de)) and not fat.isdot(@de)
				fat.write_xmm_ram(@de, SCRATCH_RAM + boty * 32, 32)
				boty++
		rec := fat.readdir(rec, @de)
	' do a bubble sort of the filenames in memory
	swapped := 1
	repeat until swapped == 0
		swapped := 0
		repeat i from 0 to boty - 2
			' read two directory entries
			fat.read_xmm_ram(@buff, SCRATCH_RAM + i * fat#dent_bytes, 2*fat#dent_bytes)
			' and compare the names
			if strncmp(@buff, @buff + fat#dent_bytes, 8) > 0
				fat.write_xmm_ram(@buff, SCRATCH_RAM + (i + 1) * fat#dent_bytes, fat#dent_bytes)
				fat.write_xmm_ram(@buff + fat#dent_bytes, SCRATCH_RAM + i * fat#dent_bytes, fat#dent_bytes)
				swapped++

PRI direntry_name(n, buf) | i, temp[fat#dent_bytes/4]
	if n < boty
		fat.read_xmm_ram(@temp, SCRATCH_RAM + n * fat#dent_bytes, fat#dent_bytes)
		if (byte[@temp][fat#dent_attr] & fat#dent_attr_D) == fat#dent_attr_D
			byte[buf] := "<"
			fat.get_dent_name(@temp, buf + 1)
			i := strsize(buf)
			byte[buf + i + 0] := ">"
			byte[buf + i + 1] := 0
		else
			fat.get_dent_name(@temp, buf)
		return 0
	return -1

PRI chdir_entry(n) | temp[fat#dent_bytes/4]
	if n < boty
		fat.read_xmm_ram(@temp, SCRATCH_RAM + n * fat#dent_bytes, fat#dent_bytes)
		fat.chdir_dent(@temp)
		return 0
	return -1

PRI open_file(fname_ptr) : fp | dent, size, sec
	dent := fat.find_file(fname_ptr)
	if dent < 0
		str(fname_ptr)
		str(string(" not found.",13,10))
		return -1
	bytemove(@de, dent, 32)
	fat.get_dent_name(@de, @name)
	size := fat.get_dent_size(@de)
	str(@name)
	str(string(" size "))
	dec_size(size)
	crlf
	fp := fat.fopen(@name, "r")

PRI xdigit(ch) | val
	val := ch - "0"
	if val < 0
		return -1
	if val > 9
		val -= 7
	if val > 15
		return -1
	return val

PRI nas_load(fname_ptr) | dent, sec, nsec, pos, state, digit, val
'' Load a file in *.NAS format to memory
	dent := open_file(fname_ptr)
	if dent < 0
		return -1
	fat.get_dent_name(dent, @name)
	sec := fat.get_dent_first_sector(@de)

	pos := $200
	state := 0
	bmin := $ffff
	bmax := $0000
	repeat
		if pos == $200
			if sec < 0
				quit
			nsec := fat.get_dent_next_sector(@de, sec)
			fat.read_sector(sec)
			sec := nsec
			pos := 0

		case state
			0:	' expecting an address
				val := byte[iobuff_ptr][pos++]
				digit := xdigit(val)
				if digit == -1
					if val == "."
						state := 5		' end of NAS file
					else
						if badr < bmin
							bmin := badr
						chr(13)
						hex(bmin, 4)
						chr("-")
						state := 1		' expect bytes
						bcnt := 8		' 8 bytes per line
						csum := badr + (badr >> 8)
				else
					badr := badr * 16 + digit	' next address digit

			1:	' expecting high nibble of a byte
				digit := xdigit(byte[iobuff_ptr][pos++])
				if digit == -1
					state := 4			' look for line feed
				else
					val := digit << 4
					state := 2			' low nibble

			2:	' expecting low nibble of a byte
				digit := xdigit(byte[iobuff_ptr][pos++])
				if digit == -1
					state := 4			' look for line feed
				else
					val := val | digit
					state := 3			' delimiting space or back space
			3:
				pos++					' ignore space (or anything)
				if bcnt--
					if bmin == 0
						vid.write_chargen(badr, @val, 1)
					elseif badr > $7ff
						fat.write_xmm_ram(@val, badr, 1)
					badr++
					csum += val
					state := 1			' next byte
				else
					if badr > bmax
						bmax := badr
					hex(bmax-1, 4)
					csum &= $ff
					if csum <> val			' checksum mismatch?
						str(string("Checksum errror - calc:"))
						hex(csum, 2)
						str(string(" got:"))
						hex(val, 2)
						str(string(" @"))
						hex(badr - 8, 4)
						crlf
						return -1
					state := 4			' look for line feed

			4:	' ignore remainder of line until next LF
				val := byte[iobuff_ptr][pos++]
				if val == 10
					badr := 0
					csum := 0
					state := 0
			5:	' finished - find next LF
				val := byte[iobuff_ptr][pos++]
				if val == 10
					badr := 0
					state := 6
			6:	' look for entry point starting with "E"
				val := byte[iobuff_ptr][pos++]
				if val == "E"				' entry point specified?
					rx_insert("E")
					chr(":")
					state := 7
				else
					state := 8
			7:	' read entry point
				val := byte[iobuff_ptr][pos++]
				digit := xdigit(val)
				if digit == -1				' non-hex digit
					hex(runaddr, 4)
					rx_insert(13)
					state := 8			' finished
				else
					rx_insert(val)
					runaddr := runaddr * 16 + digit	' next address digit
			8:	' finished
				chr(13)
				hex(bmin, 4)
				chr("-")
				hex(bmax - 1, 4)
				crlf
				if bmax == $1000			' return -1 if a font was loaded
					return -1			' from 0000 to 0fff
				return 0

DAT
'---------------------------------------------------------------------------------------------------------

		org	0

'---------------------------------------------------------------------------------------------------------
entry
iocmd_ptr	mov	iocmd_ptr, PAR
		jmp	#run

videoram_ptr	long	0-0
videoram_row0	long	15*64+10
addr		long	0
cur_x		long	0
cur_y		long	0
iobuff_ptr	long	0-0
spi_command	long	0-0
spi_blocknr	long	0-0					' SD block number for r/w commands
spi_address	long	0-0					' hub RAM address for r/w commands
x2020		long	$2020
x10_000		long	10_000

kb_head		long	0
kb_tail		long	0
kb_keys		long	@@@keybuff
kb_rate		long	0
kb_timer	long	0

' pcFullDuplexSerial2FC
tx_head0	long	0-0
tx_tail0	long	0-0
tx_buffer0	long	0-0
rx_head0	long	0-0
rx_tail0	long	0-0
rx_buffer0	long	0-0

sio_head	long	0
sio_tail	long	0
sio_temp	long	0

sio_next	long	0					' next control write is for: 0 default, 1 MASK, 2 IOR

sio_mode_a	long	0					' sio port A mode register
sio_ien_a	long	0					' interrupt enable for sio port A
sio_ivec_a	long	0					' interrupt vector for sio port A
sio_icw_a	long	0					' interrupt control word for sio port A
sio_mask_a	long	0					' mask register for sio port A
sio_ior_a	long	0					' input/output register for sio port A
sio_out_a	long	0					' port A output register
sio_inp_a	long	0					' port A input register
sio_match_a	long	0					' port A match equation

sio_mode_b	long	0					' sio port B mode register
sio_ien_b	long	0					' interrupt enable for sio port B
sio_ivec_b	long	0					' interrupt vector for sio port B
sio_icw_b	long	0					' interrupt control word for sio port B
sio_mask_b	long	0					' mask register for sio port B
sio_ior_b	long	0					' input/output register for sio port B
sio_out_b	long	0					' port B output register
sio_inp_b	long	0					' port B input register
sio_match_b	long	0					' port B match equation

rd_port_ptr	long	@@@rd_port_table
wr_port_ptr	long	@@@wr_port_table

dira_mask	long	0-0
ctra_mode	long	0-0
frqa_0		long	$0000_0000				' 0V
frqa_1		long	$d999_0000				' 0.85V of 1V, ie. 85%

port0		long	0
port1		long	0
port2		long	0
port3		long	0
port5		long	0

kbd_states	long	0-0
kbd_index	long	0

low_24bits	long	$00ffffff
low_16bits	long	$0000ffff
msg_break_ptr	long	@@@msg_break

iocmd		long	0
port		long	0
data		long	0
null		long	0

t1		long	0
t2		long	0
t3		long	0
t4		long	0

strptr		long	0
hexval		long	0
hexcnt		long	0

run
		mov	DIRA, dira_mask			' enable the sound output
		mov	CTRA, ctra_mode			' set the counter mode to single ended DUTY mode
		mov	FRQA, frqa_0			' set the default output pulse width

		rdlong	kb_rate, #0			' get clkfreq into keyboard rate
		mov	kb_timer, CNT
		add	kb_timer, kb_rate		' first key after 1 second
		shr	kb_timer, #4			' 16 keys / second afterwards

		wrlong	null, iocmd_ptr
command
		rdlong	iocmd, iocmd_ptr
		mov	t1, iocmd
		shr	t1, #24			WZ
	if_z	jmp	#command

'		mov	hexval, iocmd
'		call	#conout_hex_l
'		call	#conout_crlf

		cmp	t1, #io_cmd_out		WZ
	if_z	jmp	#output
		cmp	t1, #io_cmd_in		WZ
	if_z	jmp	#input
		cmp	t1, #io_cmd_break	WZ
	if_z	jmp	#break
command_0
		and	iocmd, low_24bits
		wrlong	iocmd, iocmd_ptr
		jmp	#command

'*******************************************
'
' Read i/o port and data to write to
'
output
		mov	port, iocmd			' get command word
		shr	port, #8			' extract port
		and	port, #$ff			' lower 8 bits
		mov	data, iocmd			' get command word
		and	data, #$ff			' extract data

		mov	t1, port
		and	t1, #7				' lower 3 bits
		add	t1, wr_port_ptr
		rdbyte	t1, t1
		jmp	t1

'*******************************************
'
' Write port #0
' bit  meaning
' ------------------------
' 7    not available
' 6    not available
' 5    unused
' 4    tape drive LED
' 3    single step logic
' 2    unused
' 1    keyboard counter reset
' 0    keyboard counter clock
'
p0_wr
		mov	t1, port0
		xor	t1, data
		test	t1, #p0_kbd_clock	WZ
	if_z	jmp	#:no_clock
		test	data, #p0_kbd_clock	WZ	' falling edge of the clock?
	if_nz	jmp	#:no_clock
		add	kbd_index, #1			' next counter value
:no_clock
		test	t1, #p0_kbd_reset	WZ	' reset keyboard counter?
	if_z	jmp	#:no_reset
		test	data, #p0_kbd_reset	WZ	' falling edge of the reset?
	if_nz	jmp	#:no_reset
		mov	kbd_index, #0			' reset counter
:no_reset
		mov	port0, data
		jmp	#command_0

'*******************************************
'
' Write port #1
' UART output data
'
p1_wr
		mov	port1, data
		call	#tx0
		jmp	#command_0		

'*******************************************
'
' Write port #2
' not assigned
'
p2_wr
		mov	port2, data
		jmp	#command_0		

'*******************************************
'
' Write port #3
' not assigned
'
p3_wr
		mov	port3, data
		jmp	#command_0		

'*******************************************
'
' Write port #4
' Data for SK.A out
'
p4_wr
		mov	t1, sio_out_a
		xor	t1, data
		test	t1, #%00000001		WZ	' bit 0 changed?
	if_z	jmp	#:no_audio
		test	data, #%00000001	WZ	' active now?
	if_z	mov	FRQA, frqa_0			' set the default output pulse width
	if_nz	mov	FRQA, frqa_1
:no_audio	mov	sio_out_a, data
		jmp	#command_0		

'*******************************************
'
' Write port #5
' Data for SK.B out
'
p5_wr
		mov	port5, data
		jmp	#command_0		

'*******************************************
'
' Write port #6
' Control for port 4
'
' bit  meaning
' -------------------------------------------------
'  0    0: set interrupt vector, enable interrupts
'  3..0 f: set operating mode bit 7+6
'             7..6 = 0: output - ready line = 1
'             7..6 = 1: input
'             7..6 = 2: bidirectional - valid for port A (B implied)
'             7..6 = 3: bit control - next write is IOR
'       7: set interrupt control word
'             bit #7 : 1 = interrupt enable   
'             bit #6 : 1 = AND logic, 0 = OR logic
'             bit #5 : 1 = active high, 0 = active low
'             bit #4 : 1 = mask follows - next write is MASK
'       3: set interrupt enable flip-flop (bit #7 of ICW)
'  others: invalid
' 
p6_wr
		test	data, #%00000001	WZ	' write the interrupt vector?
	if_nz	jmp	#:not_ivec
		mov	sio_ivec_a, data		' save the interrupt vector
		jmp	#command_0
:not_ivec
		cmp	sio_next, #0		WZ	' write control?
	if_nz	jmp	#:not_default
		mov	t1, data
		and	t1, #%00001111			' mask lower 4 bits
		cmp	t1, #%00001111		WZ	' = 15?
	if_nz	jmp	#:not_setmode			' no, not a set mode write
		mov	t1, data
		shr	t1, #6				' mode is in bits 7..6
		mov	sio_mode_a, t1
:not_setmode
		cmp	t1, #%00000111		WZ	' = 7?
	if_nz	jmp	#:not_icw			' no, not an interrupt control word write
		mov	sio_icw_a, data			' set interrupt control word for port A
		test	data, #%00010000	WZ	' interrupt mask register follows?
	if_nz	mov	sio_ien_a, #0			' clear port A IEN until mask write
	if_nz	mov	sio_match_a, #0			' clear port A logic equation
	if_nz	mov	sio_next, #1			' set flag
		jmp	#command_0
:not_icw
		cmp	t1, #%00000011		WZ	' = 3?
	if_nz	jmp	#command_0			' ignore invalid write
		mov	sio_icw_a, data			' store interrupt control word
		jmp	#:ien				' check the interrupt enable
:not_default
		cmp	sio_next, #1		WZ	' write MASK register?
	if_nz	jmp	#:not_mask
		mov	sio_mask_a, data		' write port A mask register
:ien		mov	sio_ien_a, sio_icw_a		' get interrupt control word
		shr	sio_ien_a, #7			' set port A interrupt enable
		mov	sio_next, #0			' next write is a default write
		jmp	#command_0
:not_mask
		cmp	sio_next, #2		WZ	' write IOR register?
		mov	sio_next, #0
	if_nz	jmp	#command_0
		mov	sio_ior_a, data			' set port A IOR register
		jmp	#:ien

'*******************************************
'
' Write port #7
' See port #6 for the relevant bits
'
p7_wr
		test	data, #%00000001	WZ	' write the interrupt vector?
	if_nz	jmp	#:not_ivec
		mov	sio_ivec_b, data		' save the interrupt vector
		jmp	#command_0
:not_ivec
		cmp	sio_next, #0		WZ	' write control?
	if_nz	jmp	#:not_default
		mov	t1, data
		and	t1, #%00001111			' mask lower 4 bits
		cmp	t1, #%00001111		WZ	' = 15?
	if_nz	jmp	#:not_setmode			' no, not a set mode write
		mov	t1, data
		shr	t1, #6				' mode is in bits 7..6
		mov	sio_mode_b, t1
:not_setmode
		cmp	t1, #%00000111		WZ	' = 7?
	if_nz	jmp	#:not_icw			' no, not an interrupt control word write
		mov	sio_icw_b, data			' set interrupt control word for port B
		test	data, #%00010000	WZ	' interrupt mask register follows?
	if_nz	mov	sio_ien_b, #0			' clear port B IEN until mask write
	if_nz	mov	sio_match_b, #0			' clear port B logic equation
	if_nz	mov	sio_next, #1			' set flag
		jmp	#command_0
:not_icw
		cmp	t1, #%00000011		WZ	' = 3?
	if_nz	jmp	#command_0			' ignore invalid write
		mov	sio_icw_b, data			' store interrupt control word
		jmp	#:ien				' check the interrupt enable
:not_default
		cmp	sio_next, #1		WZ	' write MASK register?
	if_nz	jmp	#:not_mask
		mov	sio_mask_b, data		' write port B mask register
:ien		mov	sio_ien_b, sio_icw_b		' get interrupt control word
		shr	sio_ien_b, #7			' set port B interrupt enable
		mov	sio_next, #0			' next write is a default write
		jmp	#command_0
:not_mask
		cmp	sio_next, #2		WZ	' write IOR register?
		mov	sio_next, #0
	if_nz	jmp	#command_0
		mov	sio_ior_b, data			' set port B IOR register
		jmp	#:ien


'*******************************************
'
' Read i/o port to read from
'
input
		andn	iocmd, #$ff			' clear the input data
		mov	port, iocmd			' get command word
		shr	port, #8
		and	port, #$ff			' lower 3 bits

		mov	t1, port
		and	t1, #7				' lower 3 bits
		add	t1, rd_port_ptr
		rdbyte	t1, t1
		jmp	t1

'*******************************************
'
' Read port #0 - keyboard data
' bit  meaning
' ------------------------
' 7    unused
' 6    S6
' 5    S3
' 4    S5
' 3    S4
' 2    S0
' 1    S2
' 0    S1
'
p0_rd
		mov	t1, kbd_index
		and	t1, #15			WZ	' 4 bit counter: 8 active columns
		cmp	t1, #9			WC	' 8 unused counter values
	if_nc	jmp	#input_ff
		and	t1, #7
		add	t1, kbd_states
		rdbyte	data, t1			' get keyboard states for column
		xor	data, #$ff
		jmp	#input_data
input_ff
		mov	data, #$ff
input_data
		and	data, #$ff
		or	iocmd, data
		jmp	#command_0

'*******************************************
'
' Read port #1
' UART input data
'
p1_rd
		call	#rx0
		jmp	#input_data

'*******************************************
'
' Read port #1
' UART status
'
p2_rd
		mov	data, #0
		rdlong	sio_head, rx_head0
		rdlong	sio_tail, rx_tail0
		cmp	sio_head, sio_tail	WZ
		muxnz	data, #p2_rbr_full		' receiver buffer full
		rdlong	sio_head, tx_head0
		rdlong	sio_tail, tx_tail0
		add	sio_head, #1
		and	sio_head, #15
		cmp	sio_head, sio_tail	WZ
		muxnz	data, #p2_tbr_empty		' transmitter buffer emptry
		' no errors
		jmp	#input_data

'*******************************************
'
' Read port #3
' not assigned
'
p3_rd
		mov	data, #$ff
		jmp	#input_data

'*******************************************
'
' Read port #4
' Data from SK.A
'
p4_rd
		cmp	sio_mode_a, #0		WZ	' output mode?
	if_nz	jmp	#:not_output
		mov	data, sio_out_a			' get port A output register
		jmp	#input_data
:not_output
		cmp	sio_mode_a, #1		WZ	' input mode?
	if_nz	jmp	#:not_input
		' TODO: call reader callback for port A
		mov	data, sio_inp_a			' get port A input register
		' TODO: set ready line for port A
		jmp	#input_data
:not_input
		cmp	sio_mode_a, #2			' bidirectional?
	if_nz	jmp	#:not_bidir
		mov	data, sio_inp_a			' get port A input register
		' TODO: set ready line for port B
		jmp	#input_data
:not_bidir
		' TODO: call reader callback for port A
		mov	data, sio_inp_a
		and	data, sio_ior_a			' mask with port A IOR
		mov	t1, sio_out_a
		andn	t1, sio_ior_a			' clear input bits in output data
		or	data, t1			' combine
		jmp	#input_data

'*******************************************
'
' Read port #5
' Data from SK.B
'
p5_rd
		cmp	sio_mode_b, #0		WZ	' output mode?
	if_nz	jmp	#:not_output
		mov	data, sio_out_b			' get port A output register
		jmp	#input_data
:not_output
		cmp	sio_mode_b, #1		WZ	' input mode?
	if_nz	jmp	#:not_input
		' TODO: call reader callback for port B
		mov	data, sio_inp_b			' get port B input register
		' TODO: set ready line for port B
		jmp	#input_data
:not_input
		cmp	sio_mode_b, #2			' bidirectional?
	if_nz	jmp	#:not_bidir
		mov	data, sio_inp_b			' get port B input register
		' TODO: set ready line for port B
		jmp	#input_data
:not_bidir
		' TODO: call reader callback for port A
		mov	data, sio_inp_b
		and	data, sio_ior_b			' mask with port B IOR
		mov	t1, sio_out_b
		andn	t1, sio_ior_b			' clear input bits in output data
		or	data, t1			' combine
		jmp	#input_data

'*******************************************
'
' Read port #6 / #7
' Return interrupt control words bit 7+6
'
p6_rd
p7_rd
		mov	data, sio_icw_a			' get interrupt control word for port A
		and	data, #%11000000		' mask bits 7+6
		mov	t1, sio_icw_b			' get interrupt control word for port B
		shr	t1, #4				' to bits 3..0
		or	data, t1			' combine
		jmp	#input_data

'*******************************************
'
' Output a character to the screen
'
conout_chr
		mov	addr, cur_y			' y
		shl	addr, #6			' * 64
		add	addr, #10			' + 10
		add	addr, cur_x			' + x
		add	addr, videoram_ptr		' + screen address

		cmp	data, #8		WZ	' backspace?
	if_z	jmp	#:bsp
		cmp	data, #9		WZ	' tab?
	if_z	jmp	#:tab
		cmp	data, #10		WZ	' line feed?
	if_z	jmp	#:lf
		cmp	data, #12		WZ	' clear screen?
	if_z	jmp	#:cls
		cmp	data, #13		WZ	' carriage return?
	if_z	jmp	#:cr
:out
		wrbyte	data, addr
		add	cur_x, #1
:wrap
		cmp	cur_x, #48		WZ
	if_nz	jmp	#:exit
		mov	cur_x, #0
:lf
		add	cur_y, #1
		cmp	cur_y, #15		WZ
	if_nz	jmp	#:exit
		call	#scroll
		mov	cur_y, #14
		jmp	#:exit

:bsp
		cmp	cur_x, #0		WZ, WC
	if_be	jmp	#:exit
		sub	cur_x, #1
		jmp	#:exit
:tab
		mov	data, #32
		wrbyte	data, addr
		add	addr, #1
		add	cur_x, #1
		test	cur_x, #7		WZ
	if_nz	jmp	#:tab
		jmp	#:wrap
:cr
		mov	cur_x, #0
		jmp	#:exit
:cls
		mov	addr, videoram_ptr
		add	addr, #10
		mov	cur_y, #16
:clsrow		mov	cur_x, #48/2
:clscol		wrword	x2020, addr
		add	addr, #2
		djnz	cur_x, #:clscol
		add	addr, #16
		djnz	cur_y, #:clsrow
:exit
conout_chr_ret
		ret		

'*******************************************
'
' Scroll the screen one line up
'
scroll
		mov	addr, videoram_ptr
		add	addr, #10
		mov	cur_y, #14
:row		mov	cur_x, #48/2
:col		add	addr, #64
		rdword	data, addr
		sub	addr, #64
		wrword	data, addr
		add	addr, #2
		djnz	cur_x, #:col
		add	addr, #16
		djnz	cur_y, #:row
		mov	cur_x, #48/2
:fill		wrword	x2020, addr
		add	addr, #2
		djnz	cur_x, #:fill
scroll_ret
		ret


'*******************************************
'
' Output a byte in hexval to the console
'
conout_hex_b
		mov	hexcnt, #2
		shl	hexval, #24
		jmp	#conout_hex

'*******************************************
'
' Output a word in hexval to the console
'
conout_hex_w
		mov	hexcnt, #4
		shl	hexval, #16
		jmp	#conout_hex

'*******************************************
'
' Output a long in hexval to the console
'
conout_hex_l
		mov	hexcnt, #8
conout_hex
		mov	data, hexval
		shr	data, #28
		cmp	data, #10	WZ, WC
	if_b	add	data, #48
	if_ae	add	data, #55
		call	#conout_chr
		shl	hexval, #4
		djnz	hexcnt, #conout_hex
conout_hex_ret
conout_hex_l_ret
conout_hex_w_ret
conout_hex_b_ret
		ret

'*******************************************
'
' Output a carriage return to the console
'
conout_space
		mov	data, #32
		call	#conout_chr
conout_space_ret
		ret

'*******************************************
'
' Output a carriage return to the console
'
conout_crlf
		mov	data, #13
		call	#conout_chr
		mov	data, #10
		call	#conout_chr
conout_crlf_ret
		ret

'*******************************************
'
' Output a string at strptr to the console
'
conout_string
		rdbyte	data, strptr	WZ
		add	strptr, #1
	if_z	jmp	#conout_string_ret
		call	#conout_chr
		jmp	#conout_string
conout_string_ret
		ret

'**********************************************************************************************
'
' Write to the FullDuplexSerial tx_buffer0
'
tx0
:wait
		rdlong	sio_head, tx_head0
		mov	sio_temp, sio_head
		add	sio_head, #1
		rdlong	sio_tail, tx_tail0
		and	sio_head, #15
		cmp	sio_head, sio_tail	WZ
	if_z	jmp	#:wait					' wait until there's room in the buffer
		add	sio_temp, tx_buffer0
		wrbyte	data, sio_temp
		wrlong	sio_head, tx_head0			' increment the tx_head0
tx0_ret
		ret

'**********************************************************************************************
'
' Read from the FullDuplexSerial rx_buffer0
'
rx0
		mov	data, #0				' no data available
		rdlong	sio_head, rx_head0
		rdlong	sio_tail, rx_tail0
		cmp	sio_head, sio_tail	WZ
	if_z	jmp	rx0_ret
		mov	sio_temp, rx_buffer0
		add	sio_temp, sio_tail
		rdbyte	data, sio_temp		WZ
		add	sio_tail, #1
		and	sio_tail, #255
		wrlong	sio_tail, rx_tail0
rx0_ret
		ret
'*******************************************
'
' Break - issued when the Z80 encounters
' a HALT instruction.
'
break
		mov	t1, iocmd			' read the address of the register file
		shr	t1, #8				' bits 23..8 to 15..0
		and	t1, low_16bits			' mask only bits 15..0
		mov	strptr, msg_break_ptr	

		mov	t2, #8
:loop_1		call	#conout_string
		rdword	hexval, t1			' read BC, DE, HL, AF, BC', DE', HL', AF'
		call	#conout_hex_w
		add	t1, #2
		djnz	t2, #:loop_1

		call	#conout_string			' new line and print "R:"
		rdbyte	hexval, t1			' R
		add	t1, #1
		rdbyte	t2, t1				' R2
		and	hexval, #%01111111		' R register's bit #7
		or	hexval, t2			' does never change from the last written value
		call	#conout_hex_b
		add	t1, #1

		call	#conout_string
		rdbyte	hexval, t1			' IFF1+2/IM
		mov	t2, t1				' save value
		and	hexval, #1			' IFF1 (interrupt flip-flop 1)
		call	#conout_hex_b

		call	#conout_string
		mov	hexval, t2			' IFF1+2/IM
		shr	hexval, #1			' shift bit #1 to #0
		and	hexval, #1			' IFF2 (interrupt flip-flop 2)
		call	#conout_hex_b

		call	#conout_string
		mov	hexval, t2			' IFF1+2/IM
		shr	hexval, #2			' shift bits #3..2 to #1..0
		and	hexval, #3			' IM (interrupt mode)
		call	#conout_hex_b
		add	t1, #1

		call	#conout_string
		rdbyte	hexval, t1			' I (interrupt vector register)
		call	#conout_hex_b
		add	t1, #1

		mov	t2, #4
:loop2		call	#conout_string
		rdword	hexval, t1			' IX, IY, SP, PC
		mov	t3, hexval
		call	#conout_hex_w
		add	t1, #2
		djnz	t2, #:loop2

		call	#conout_string

		mov	t2, #4				' 4 bytes
		shl	t2, #16
		or	t2, t1				' length in upper 16 bits, hub memory address in lower 16 bits
		wrlong	t2, spi_address			' as hub RAM address + length
		wrlong	t3, spi_blocknr			' PC as XMM address
		mov	t4, #"R"			' XMM read command
		wrlong	t4, spi_command
:wait		rdlong	t4, spi_command		WZ
	if_nz	jmp	#:wait

		rdbyte	hexval, t1
		call	#conout_hex_b
		call	#conout_crlf
		jmp	#command_0

		fit	$1f0
'
' Nascom video ram is organized as 64x16, but only 48x16 are displayed
' The odd thing about the Nascom is that the first display character
' comes from row #15 column #10!
'
videoram	byte	0[64*16]
sync		long	0

rd_port_table	byte	p0_rd, p1_rd, p2_rd, p3_rd, p4_rd, p5_rd, p6_rd, p7_rd
wr_port_table	byte	p0_wr, p1_wr, p2_rd, p3_wr, p4_wr, p5_wr, p6_wr, p7_wr

keybuff		byte	0[32]

msg_break	byte	"BC:",0
		byte	" DE:",0
		byte	" HL:",0
		byte	" AF:",0
		byte	" BC'",0
		byte	" DE'",0
		byte	" HL'",0
		byte	" AF'",0
		byte	13,10, "R:",0
		byte	" IFF1:",0
		byte	" IFF2:",0
		byte	" IM:",0
		byte	" I:",0
		byte	" IX:",0
		byte	" IY:",0
		byte	" SP:",0
		byte	" PC:",0
		byte	" = ",0

''      MIT LICENSE
{{
'  Permission is hereby granted, free of charge, to any person obtaining
'  a copy of this software and associated documentation files
'  (the "Software"), to deal in the Software without restriction,
'  including without limitation the rights to use, copy, modify, merge,
'  publish, distribute, sublicense, and/or sell copies of the Software,
'  and to permit persons to whom the Software is furnished to do so,
'  subject to the following conditions:
'
'  The above copyright notice and this permission notice shall be included
'  in all copies or substantial portions of the Software.
'
'  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
'  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
'  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
'  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
'  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
'  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
'  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
}}
