'******************************************************************************
'*  Nascom video.spin - Display a Nascom video buffer of 48x16 characters
'*
'*  This is based on ideas and code from Debug_1pinTV by "Cluso99"
'*
'*  (c) Juergen Buchmueller <pullmoll@t-online.de>
'*
'* $Id: video.spin,v 1.4 2010-05-02 16:20:38 pm Exp $
'******************************************************************************
CON
	_xinfreq		= 5_000_000		' Quartz is 5MHz
	_clkmode		= xtal1 + pll16x	' System clock is 80MHz

'Define this to use the full height 8x16 font, pushing the TV to its limits (or beyond in case of NTSC)
'#define USE_8x16

#ifdef NTSC
'' NTSC 48x16 at 8x15px - this is outside the specs of NTSC, so you probably have to tune your monitor!
ocols			=	48			' number of columns
orows			=	16			' number of rows
ocolsfrq		=	22_478			' Hz per active pixel
oequal1			=	6			' number of equalization pulses
oserr			=	6			' number of serration pulses
oequal2			=	6			' number of equalization pulses
#ifdef USE_8x16
oblank1			=	12			' number of blank lines
oactive			=	256			' number of active lines
oblank2			=	1			' number of blank lines
#else
oblank1			=	12			' number of blank lines
oactive			=	240			' number of active lines
oblank2			=	1			' number of blank lines
#endif
ohalf			=	274			' VSCL half line
obackp			=	75	 		' VSCL back porch (sync to active)
ofrontp			=	49			' VSCL front porch (active to sync)
oequal			=	20			' VSCL equalization pulse (sync/2)
osync			=	40			' VSCL sync pulse
osynch			=	234			' VSCL half-sync
oequalh			=	254			' VSCL half-equal
ovsclch			=	32			' VSCL character (24 pixels)
ictra			=	12			' CTRA with PLLdiv
ifrqa			=	231701456		' required FRQA value (5MHz*16) (xfrqa replaced by start routine)
ifrqb			=	$4924_0000		' 40/140 << 32 = 1,227,096,064

ifrqa_80MHz		=	231701456		' required FRQA value (5MHz*16)
ifrqa_96MHz		=	257446064		' required FRQA value (6MHz*16)
ifrqa_100MHz		=	247148224		' required FRQA value (6.25MHz*16)
ifrqa_104MHz		=	237642512		' required FRQA value (6.5MHz*16)
ifrqa_108MHz		=	228840944		' required FRQA value (13.5MHz*8)
ifrqa_114MHz		=	161813984		' required FRQA value (14.318318MHz*8)
#endif

'--------------------------------------------------------------------------------------------------
#ifdef PAL
'' PAL	48x16 at 8x15px
ocols			=	48			' number of columns
orows			=	16			' number of rows
ocolsfrq		=	22_321			' Hz per active pixel
oequal1			=	4			' number of equalization pulses
oserr			=	5			' number of serration pulses
oequal2			=	5			' number of equalization pulses
#ifdef USE_8x16
oblank1			=	38			' number of blank lines
oactive			=	256			' number of active lines
oblank2			=	10			' number of blank lines
#else
oblank1			=	39			' number of blank lines
oactive			=	240			' number of active lines
oblank2			=	25			' number of blank lines
#endif
ohalf			=	273			' VSCL half line
obackp			=	80			' VSCL back porch (sync to active)
ofrontp			=	43			' VSCL front porch (active to sync)
oequal			=	19			' VSCL equalization pulse (sync/2)
osync			=	39			' VSCL sync pulse
osynch			=	234			' VSCL half-sync
oequalh			=	254			' VSCL half-equal
ovsclch			=	32			' VSCL character (24 pixels)
ictra			=	12			' CTRA with PLLdiv
ifrqa			=	230083104		' required FRQA value (5MHz*16) (xfrqa replaced by start routine)
ifrqb			=	$4924_0000		' 40/140 << 32 = 1,227,096,064

ifrqa_80MHz		=	230083104		' required FRQA value (5MHz*16)
ifrqa_96MHz		=	191735920		' required FRQA value (6MHz*16)
ifrqa_100MHz		=	184066480		' required FRQA value (6.25MHz*16)
ifrqa_104MHz		=	176987008		' required FRQA value (6.5MHz*16)
ifrqa_108MHz		=	170431936		' required FRQA value (13.5MHz*8)
ifrqa_114MHz		=	160683776		' required FRQA value (14.318318MHz*8)
#endif
'--------------------------------------------------------------------------------------------------

VAR
	long	cog

PUB start(params) : okay
' bitmap is the address of the bitmap buffer * 32 + the tvPin number

	stop
	Setforxtalfreq					'set ifrqa in hub for the current clkfreq before cognew 
	screen_ptr := long[params][0]
	screen_end := long[params][0] + 16*64
	screen_row0 := long[params][0] + 15*64 + 10

	pin_no := long[params][1]
	okay := cog := COGNEW(@entry, 0) + 1

PUB stop
	if cog
		COGSTOP(cog - 1)
		cog := 0

PUB write_chargen(offs, src, size) | addr, i
'' Write the character generator
	repeat i from offs to offs + size - 1
		addr := ((i & 15) << 8) + ((i >> 4) & $ff)
		byte[@font][addr] := byte[src++] >< 8

PRI Setforxtalfreq
'' Set the frqa value depending on the actual clkfreq
	Case clkfreq / 1_000_000
		 80: xfrqa := ifrqa_80MHz	'  5.00 MHz
		 96: xfrqa := ifrqa_96MHz	'  6.00 MHz
		100: xfrqa := ifrqa_100MHz	'  6.25 MHz
		104: xfrqa := ifrqa_104MHz	'  6.50 MHz
		108: xfrqa := ifrqa_108MHz	' 13.50 MHz
		114: xfrqa := ifrqa_114MHz      ' 14.318318 MHz
DAT
		org	0
entry
		mov	FRQB, xfrqb			' default = 40/140

		movi	CTRA, #ictra
		mov	FRQA, xfrqa

		movs	CTRB, pin_no			' set pin
		mov	count, #1
		shl	count, pin_no
		mov	DIRA, count			' set pin mask
		mov	count, pin_no
		shr	count, #3
		movd	VCFG, count			' set VGroup
		mov	count, #1
		and	pin_no, #7
		shl	count, pin_no
		movs	VCFG, count			' set VPins
		movi	VCFG, #%0_01_0_0_0_000		' VGA mode, 1 bit per pixel
		movd	VSCL, #(1 << 3)			' 1 PLL per pixel

'**************************************************************************************************
frame		add	framectr, #1			' inc frame counter
		mov	rows, #oequal1
		call	#equalizing
'--------------------------------------------------------------------------------------------------
		mov	rows, #oserr			' serration pulses
		call	#serration
'--------------------------------------------------------------------------------------------------
		mov	rows, #oequal2
		call	#equalizing
'==================================================================================================
		mov	rows, #oblank1
		call	#doblank
'==================================================================================================
'display active lines
		mov	fontindex, font_ptr
		mov	scrptr0, screen_row0		' initialize bitmap pointer
		mov	rows, #oactive
doactive
		movs	VSCL, #osync			' 4.7uSec @ -40 IRE
		waitvid xFF00, #0
		movi	CTRB, #0			' turn off blank
		movs	VSCL, #obackp			' back porch
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		movs	VSCL, #ovsclch			' 1 PLLA per pixel, 24 PLLA per frame
		mov	count, #ocols/4			' character sper line / 2, since we do 2 at a time
		mov	scrptr, scrptr0
'--------------------------------------------------------------------------------------------------
:active
		rdbyte	ch, scrptr			' fetch character code
		add	scrptr, #1			' advance to next byte
		add	ch, fontindex			' + fontindex = address of font long
		rdbyte	bits0, ch			' read to bits0

		rdbyte	ch, scrptr			' fetch character code
		add	scrptr, #1			' advance to next byte
		add	ch, fontindex			' + fontindex = address of font long
		rdbyte	bits1, ch			' read to bits1
		shl	bits1, #8
		or	bits0, bits1

		rdbyte	ch, scrptr			' fetch character code
		add	scrptr, #1			' advance to next byte
		add	ch, fontindex			' + fontindex = address of font long
		rdbyte	bits2, ch			' read to bits2
		shl	bits2, #16
		or	bits0, bits2

		rdbyte	ch, scrptr			' fetch character code
		add	scrptr, #1			' advance to next byte
		add	ch, fontindex			' fourth character + fontindex = address of font byte
		rdbyte	bits3, ch			' read to bits3
		shl	bits3, #24			' put bitmask 3 in 23..18
		or	bits0, bits3

		waitvid	xFF00, bits0			' output to screen
		djnz	count, #:active			' do entire line
'--------------------------------------------------------------------------------------------------
		movs	VSCL, #ofrontp			' front porch
		waitvid xFF00, #0			' output blank

		add	fontindex, #256
		cmp	fontindex, font_end	WZ
	if_z	mov	fontindex, font_ptr
	if_z	add	scrptr0, #ocols+16
		cmp	scrptr0, screen_end	WZ, WC
	if_ae	mov	scrptr0, screen_ptr
	if_ae	add	scrptr0, #10

		djnz	rows, #doactive			' next row
'==================================================================================================
		mov	rows, #oblank2
		call	#doblank
'==================================================================================================
		jmp	#frame
'**************************************************************************************************
equalizing
		movs	VSCL, #oequal			' equalizing pulse (short)
		waitvid xFF00, #0
		movi	CTRB, #0			' turn off blank
		movs	VSCL, #oequalh			' equalizing pulse (long)
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		djnz	rows, #equalizing
equalizing_ret
		ret
'--------------------------------------------------------------------------------------------------
serration
		movs	VSCL, #osynch			' serration pulse (long)
		waitvid xFF00, #0		
		movi	CTRB, #0			' turn off blank
		movs	VSCL, #osync			' serration pulse (short)
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		djnz	rows, #serration
serration_ret
		ret
'--------------------------------------------------------------------------------------------------
doblank
		movs	VSCL, #osync			' 4.7uSec @ -40 IRE
		waitvid xFF00, #0
		movi	CTRB, #0			' turn off blank
		movs	VSCL, #osynch			' serration pulse (long)
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		movs	VSCL, #ohalf			' half line ???
		waitvid xFF00, #0
		djnz	rows, #doblank
doblank_ret
		ret
'--------------------------------------------------------------------------------------------------
'constants > $1FF
xhalf		long	ohalf
xfrqa		long	ifrqa
xfrqb		long	ifrqb

xFF00		long	$FF00			' white / black
font_ptr	long	@@@font
#ifdef USE_8x16
font_end	long	@@@font + 256*16
#else
font_end	long	@@@font + 256*15
#endif
screen_ptr	long	0-0
screen_end	long	0-0
screen_row0	long	0-0
pin_no		long	0

ch		long	0
ch4		long	0
bits0		long	0
bits1		long	0
bits2		long	0
bits3		long	0
fontindex	long	0
fontshift	long	0
scrptr0		long	0			' pointer to screen data per character row
scrptr		long	0			' pointer to screen data per scanline
framectr	long	0
count		long	0			' all purpose counter
rows		long	0			' row counter
t1		long	0

		fit	$1f0

font				' scanrow 0
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%00010000	' ....#...
		byte	%10000000	' .......#
		byte	%00000100	' ..#.....
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00111000	' ...###..
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00111000	' ...###..
		byte	%00111000	' ...###..
		byte	%11111110	' .#######
		byte	%00111000	' ...###..
		byte	%00111000	' ...###..
		byte	%00111000	' ...###..
		byte	%00111000	' ...###..
		byte	%00000000	' ........
		byte	%01111100	' ..#####.
		byte	%10000000	' .......#
		byte	%11111110	' .#######
		byte	%00010000	' ....#...
		byte	%00111100	' ..####..
		byte	%00111000	' ...###..
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00100100	' ..#..#..
		byte	%00111000	' ...###..
		byte	%00010000	' ....#...
		byte	%00000100	' ..#.....
		byte	%00011100	' ..###...
		byte	%00110000	' ....##..
		byte	%00100000	' .....#..
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01111100	' ..#####.
		byte	%00010000	' ....#...
		byte	%01111100	' ..#####.
		byte	%01111100	' ..#####.
		byte	%01000000	' ......#.
		byte	%11111110	' .#######
		byte	%01111000	' ...####.
		byte	%11111110	' .#######
		byte	%01111100	' ..#####.
		byte	%01111100	' ..#####.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%01111000	' ...####.
		byte	%01111000	' ...####.
		byte	%00111000	' ...###..
		byte	%01111110	' .######.
		byte	%01111000	' ...####.
		byte	%00111110	' .#####..
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%01111000	' ...####.
		byte	%10000010	' .#.....#
		byte	%01111100	' ..#####.
		byte	%11111000	' ...#####
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00111000	' ...###..
		byte	%01111110	' .######.
		byte	%00111000	' ...###..
		byte	%01111110	' .######.
		byte	%01111100	' ..#####.
		byte	%11111110	' .#######
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%11111110	' .#######
		byte	%00111100	' ..####..
		byte	%00000000	' ........
		byte	%00111100	' ..####..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00011000	' ...##...
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00110000	' ....##..
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%00011000	' ...##...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00110000	' ....##..
		byte	%00010000	' ....#...
		byte	%00011000	' ...##...
		byte	%11111110	' .#######
		byte	%00100100	' ..#..#..
		byte	%10101010	' .#.#.#.#
		byte	%00000000	' ........
		byte	%00000001	' #.......
		byte	%10000000	' .......#
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000001	' #.......
		byte	%10000000	' .......#
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11101110	' .###.###
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%11110000	' ....####
		byte	%00011111	' #####...
		byte	%11111111	' ########
		byte	%00101000	' ...#.#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000100	' ..#.....
		byte	%00001110	' .###....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01110000	' ....###.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%11100000	' .....###
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%00111100	' ..####..
		byte	%00111100	' ..####..
		byte	%00111100	' ..####..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00001000	' ...#....
		byte	%00100010	' .#...#..
		byte	%00001000	' ...#....
		byte	%00011100	' ..###...
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########

				' scanrow 1
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%10000000	' .......#
		byte	%00001000	' ...#....
		byte	%10000010	' .#.....#
		byte	%10000000	' .......#
		byte	%01000100	' ..#...#.
		byte	%00000100	' ..#.....
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%01000100	' ..#...#.
		byte	%01000100	' ..#...#.
		byte	%10000010	' .#.....#
		byte	%01010100	' ..#.#.#.
		byte	%01000100	' ..#...#.
		byte	%01000100	' ..#...#.
		byte	%01010100	' ..#.#.#.
		byte	%10001000	' ...#...#
		byte	%01000100	' ..#...#.
		byte	%10000000	' .......#
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%01000010	' .#....#.
		byte	%01000100	' ..#...#.
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00100100	' ..#..#..
		byte	%01000100	' ..#...#.
		byte	%11111100	' ..######
		byte	%10001010	' .#.#...#
		byte	%00100010	' .#...#..
		byte	%00110000	' ....##..
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%10000000	' .......#
		byte	%10000010	' .#.....#
		byte	%00011000	' ...##...
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%01100000	' .....##.
		byte	%00000010	' .#......
		byte	%00000100	' ..#.....
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%10000100	' ..#....#
		byte	%10000100	' ..#....#
		byte	%01000100	' ..#...#.
		byte	%10000100	' ..#....#
		byte	%10000100	' ..#....#
		byte	%01000100	' ..#...#.
		byte	%00000010	' .#......
		byte	%00000010	' .#......
		byte	%10000100	' ..#....#
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%01000010	' .#....#.
		byte	%00000010	' .#......
		byte	%11000110	' .##...##
		byte	%10000110	' .##....#
		byte	%01000100	' ..#...#.
		byte	%10000010	' .#.....#
		byte	%01000100	' ..#...#.
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000000	' .......#
		byte	%00000100	' ..#.....
		byte	%00000010	' .#......
		byte	%00100000	' .....#..
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00011000	' ...##...
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%01001000	' ...#..#.
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%01000000	' ......#.
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%10010010	' .#..#..#
		byte	%01010101	' #.#.#.#.
		byte	%00110011	' ##..##..
		byte	%00000010	' .#......
		byte	%01000000	' ......#.
		byte	%11111110	' .#######
		byte	%01111111	' #######.
		byte	%00000011	' ##......
		byte	%11000000	' ......##
		byte	%01000000	' ......#.
		byte	%00000010	' .#......
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11101110	' .###.###
		byte	%11111111	' ########
		byte	%01111110	' .######.
		byte	%11111100	' ..######
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00101000	' ...#.#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000110	' .##.....
		byte	%00000110	' .##.....
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010010	' .#..#...
		byte	%01001000	' ...#..#.
		byte	%00100000	' .....#..
		byte	%00101000	' ...#.#..
		byte	%01000100	' ..#...#.
		byte	%00100000	' .....#..
		byte	%00000100	' ..#.....
		byte	%00100100	' ..#..#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00011100	' ..###...
		byte	%01110111	' ###.###.
		byte	%00011100	' ..###...
		byte	%00011100	' ..###...
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########

				' scanrow 2
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%10000000	' .......#
		byte	%00010000	' ....#...
		byte	%11000110	' .##...##
		byte	%01000000	' ......#.
		byte	%10000010	' .#.....#
		byte	%00111110	' .#####..
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%01010100	' ..#.#.#.
		byte	%00001000	' ...#....
		byte	%11000110	' .##...##
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%01010000	' ....#.#.
		byte	%01000100	' ..#...#.
		byte	%10000000	' .......#
		byte	%01000100	' ..#...#.
		byte	%00010000	' ....#...
		byte	%01000010	' .#....#.
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00100100	' ..#..#..
		byte	%00000100	' ..#.....
		byte	%00010010	' .#..#...
		byte	%01000100	' ..#...#.
		byte	%00100010	' .#...#..
		byte	%00010000	' ....#...
		byte	%00001000	' ...#....
		byte	%00100000	' .....#..
		byte	%10010010	' .#..#..#
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%11000010	' .#....##
		byte	%00010100	' ..#.#...
		byte	%10000000	' .......#
		byte	%10000000	' .......#
		byte	%01010000	' ....#.#.
		byte	%00000010	' .#......
		byte	%00000010	' .#......
		byte	%01000000	' ......#.
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%10000100	' ..#....#
		byte	%10110010	' .#..##.#
		byte	%10000010	' .#.....#
		byte	%10000100	' ..#....#
		byte	%00000010	' .#......
		byte	%10000100	' ..#....#
		byte	%00000010	' .#......
		byte	%00000010	' .#......
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00100010	' .#...#..
		byte	%00000010	' .#......
		byte	%10101010	' .#.#.#.#
		byte	%10001010	' .#.#...#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%01000100	' ..#...#.
		byte	%01000100	' ..#...#.
		byte	%01000000	' ......#.
		byte	%00000100	' ..#.....
		byte	%00000100	' ..#.....
		byte	%00100000	' .....#..
		byte	%00111000	' ...###..
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%01001000	' ...#..#.
		byte	%10101010	' .#.#.#.#
		byte	%00110011	' ##..##..
		byte	%00000010	' .#......
		byte	%01000000	' ......#.
		byte	%11111110	' .#######
		byte	%01111111	' #######.
		byte	%00000011	' ##......
		byte	%11000000	' ......##
		byte	%00100000	' .....#..
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11101110	' .###.###
		byte	%11111111	' ########
		byte	%00111110	' .#####..
		byte	%11111000	' ...#####
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00101000	' ...#.#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000100	' ..#.....
		byte	%00001100	' ..##....
		byte	%00000000	' ........
		byte	%01110000	' ....###.
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00001000	' ...#....
		byte	%10000000	' .......#
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00100100	' ..#..#..
		byte	%00100100	' ..#..#..
		byte	%00100000	' .....#..
		byte	%01000100	' ..#...#.
		byte	%00101000	' ...#.#..
		byte	%00100000	' .....#..
		byte	%00000100	' ..#.....
		byte	%00100100	' ..#..#..
		byte	%01111100	' ..#####.
		byte	%01111100	' ..#####.
		byte	%11000011	' ##....##
		byte	%11000011	' ##....##
		byte	%00111110	' .#####..
		byte	%01111111	' #######.
		byte	%00011100	' ..###...
		byte	%01111111	' #######.
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########

				' scanrow 3
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%10000000	' .......#
		byte	%00100000	' .....#..
		byte	%10101010	' .#.#.#.#
		byte	%00100000	' .....#..
		byte	%10000010	' .#.....#
		byte	%01000100	' ..#...#.
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00111000	' ...###..
		byte	%00000100	' ..#.....
		byte	%10101010	' .#.#.#.#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%00100000	' .....#..
		byte	%01000100	' ..#...#.
		byte	%10000000	' .......#
		byte	%00101000	' ...#.#..
		byte	%00111000	' ...###..
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00010010	' .#..#...
		byte	%00100000	' .....#..
		byte	%00010100	' ..#.#...
		byte	%00001000	' ...#....
		byte	%00001000	' ...#....
		byte	%00100000	' .....#..
		byte	%01010100	' ..#.#.#.
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%10100010	' .#...#.#
		byte	%00010000	' ....#...
		byte	%01000000	' ......#.
		byte	%10000000	' .......#
		byte	%01001000	' ...#..#.
		byte	%00111110	' .#####..
		byte	%00000010	' .#......
		byte	%00100000	' .....#..
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00011000	' ...##...
		byte	%00011000	' ...##...
		byte	%00000100	' ..#.....
		byte	%01111100	' ..#####.
		byte	%01000000	' ......#.
		byte	%10000000	' .......#
		byte	%10101010	' .#.#.#.#
		byte	%10000010	' .#.....#
		byte	%10000100	' ..#....#
		byte	%00000010	' .#......
		byte	%10000100	' ..#....#
		byte	%00000010	' .#......
		byte	%00000010	' .#......
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00010010	' .#..#...
		byte	%00000010	' .#......
		byte	%10010010	' .#..#..#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%01000100	' ..#...#.
		byte	%10000010	' .#.....#
		byte	%00101000	' ...#.#..
		byte	%00101000	' ...#.#..
		byte	%00100000	' .....#..
		byte	%00000100	' ..#.....
		byte	%00001000	' ...#....
		byte	%00100000	' .....#..
		byte	%01010100	' ..#.#.#.
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%00111100	' ..####..
		byte	%00111010	' .#.###..
		byte	%00111100	' ..####..
		byte	%01011100	' ..###.#.
		byte	%00111100	' ..####..
		byte	%00001000	' ...#....
		byte	%01011100	' ..###.#.
		byte	%00111010	' .#.###..
		byte	%00011000	' ...##...
		byte	%01100000	' .....##.
		byte	%00100010	' .#...#..
		byte	%00010000	' ....#...
		byte	%01101110	' .###.##.
		byte	%00111010	' .#.###..
		byte	%00111100	' ..####..
		byte	%00111010	' .#.###..
		byte	%01011100	' ..###.#.
		byte	%00111010	' .#.###..
		byte	%00111100	' ..####..
		byte	%00111110	' .#####..
		byte	%01000010	' .#....#.
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%01111110	' .######.
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%00100100	' ..#..#..
		byte	%01010101	' #.#.#.#.
		byte	%11001100	' ..##..##
		byte	%00000100	' ..#.....
		byte	%00100000	' .....#..
		byte	%11111100	' ..######
		byte	%00111111	' ######..
		byte	%00000111	' ###.....
		byte	%11100000	' .....###
		byte	%00010000	' ....#...
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11101110	' .###.###
		byte	%11111111	' ########
		byte	%10011110	' .####..#
		byte	%11110010	' .#..####
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%11111110	' .#######
		byte	%00110110	' .##.##..
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000100	' ..#.....
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%10001000	' ...#...#
		byte	%00000000	' ........
		byte	%00110000	' ....##..
		byte	%00000000	' ........
		byte	%11111100	' ..######
		byte	%00101000	' ...#.#..
		byte	%00010000	' ....#...
		byte	%01000000	' ......#.
		byte	%00001100	' ..##....
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%01001000	' ...#..#.
		byte	%00010010	' .#..#...
		byte	%00100000	' .....#..
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00111100	' ..####..
		byte	%00111100	' ..####..
		byte	%00111100	' ..####..
		byte	%10000010	' .#.....#
		byte	%11111110	' .#######
		byte	%10000001	' #......#
		byte	%10111101	' #.####.#
		byte	%01111111	' #######.
		byte	%00111110	' .#####..
		byte	%00111110	' .#####..
		byte	%01111111	' #######.
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########

				' scanrow 4
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%10000000	' .......#
		byte	%01111100	' ..#####.
		byte	%10010010	' .#..#..#
		byte	%00010010	' .#..#...
		byte	%10000010	' .#.....#
		byte	%10001000	' ...#...#
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%10010010	' .#..#..#
		byte	%00010000	' ....#...
		byte	%11111110	' .#######
		byte	%10010010	' .#..#..#
		byte	%10010010	' .#..#..#
		byte	%11111110	' .#######
		byte	%11110010	' .#..####
		byte	%11110010	' .#..####
		byte	%10011110	' .####..#
		byte	%10011110	' .####..#
		byte	%01010010	' .#..#.#.
		byte	%01000100	' ..#...#.
		byte	%11111110	' .#######
		byte	%00010000	' ....#...
		byte	%00111000	' ...###..
		byte	%00001100	' ..##....
		byte	%11111110	' .#######
		byte	%10011110	' .####..#
		byte	%10011110	' .####..#
		byte	%11110010	' .#..####
		byte	%11110010	' .#..####
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00001110	' .###....
		byte	%01111100	' ..#####.
		byte	%00010000	' ....#...
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00100000	' .....#..
		byte	%00111000	' ...###..
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%10010010	' .#..#..#
		byte	%00010000	' ....#...
		byte	%00111000	' ...###..
		byte	%01111000	' ...####.
		byte	%01000100	' ..#...#.
		byte	%01000000	' ......#.
		byte	%01111110	' .######.
		byte	%00010000	' ....#...
		byte	%01111100	' ..#####.
		byte	%11111100	' ..######
		byte	%00011000	' ...##...
		byte	%00011000	' ...##...
		byte	%00000010	' .#......
		byte	%00000000	' ........
		byte	%10000000	' .......#
		byte	%01100000	' .....##.
		byte	%10101010	' .#.#.#.#
		byte	%11111110	' .#######
		byte	%01111100	' ..#####.
		byte	%00000010	' .#......
		byte	%10000100	' ..#....#
		byte	%00011110	' .####...
		byte	%00011110	' .####...
		byte	%00000010	' .#......
		byte	%11111110	' .#######
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00001010	' .#.#....
		byte	%00000010	' .#......
		byte	%10010010	' .#..#..#
		byte	%10100010	' .#...#.#
		byte	%10000010	' .#.....#
		byte	%01111110	' .######.
		byte	%10000010	' .#.....#
		byte	%01111110	' .######.
		byte	%01111100	' ..#####.
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%01000100	' ..#...#.
		byte	%10010010	' .#..#..#
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000100	' ..#.....
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%10010010	' .#..#..#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%01000110	' .##...#.
		byte	%01000010	' .#....#.
		byte	%01100010	' .#...##.
		byte	%01000010	' .#....#.
		byte	%00111110	' .#####..
		byte	%01100010	' .#...##.
		byte	%01000110	' .##...#.
		byte	%00010000	' ....#...
		byte	%01000000	' ......#.
		byte	%00010010	' .#..#...
		byte	%00010000	' ....#...
		byte	%10010010	' .#..#..#
		byte	%01000110	' .##...#.
		byte	%01000010	' .#....#.
		byte	%01000110	' .##...#.
		byte	%01100010	' .#...##.
		byte	%01000110	' .##...#.
		byte	%01000010	' .#....#.
		byte	%00001000	' ...#....
		byte	%01000010	' .#....#.
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%00100100	' ..#..#..
		byte	%01000010	' .#....#.
		byte	%00100000	' .....#..
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%10010010	' .#..#..#
		byte	%10101010	' .#.#.#.#
		byte	%11001100	' ..##..##
		byte	%00000100	' ..#.....
		byte	%00100000	' .....#..
		byte	%11111100	' ..######
		byte	%00111111	' ######..
		byte	%00000111	' ###.....
		byte	%11100000	' .....###
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11101110	' .###.###
		byte	%00000000	' ........
		byte	%11001110	' .###..##
		byte	%11100110	' .##..###
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00101000	' ...#.#..
		byte	%01001001	' #..#..#.
		byte	%00000000	' ........
		byte	%00001110	' .###....
		byte	%00001110	' .###....
		byte	%00001110	' .###....
		byte	%10001100	' ..##...#
		byte	%10001000	' ...#...#
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%01000100	' ..#...#.
		byte	%00101010	' .#.#.#..
		byte	%00101000	' ...#.#..
		byte	%00100000	' .....#..
		byte	%11111110	' .#######
		byte	%10010010	' .#..#..#
		byte	%00010000	' ....#...
		byte	%11111110	' .#######
		byte	%10010000	' ....#..#
		byte	%00001001	' #..#....
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%11111110	' .#######
		byte	%00011000	' ...##...
		byte	%00011000	' ...##...
		byte	%00011000	' ...##...
		byte	%10000010	' .#.....#
		byte	%11111110	' .#######
		byte	%10000001	' #......#
		byte	%10111101	' #.####.#
		byte	%01111111	' #######.
		byte	%00111110	' .#####..
		byte	%01111111	' #######.
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11111111	' ########

				' scanrow 5
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%10000000	' .......#
		byte	%00001000	' ...#....
		byte	%10101010	' .#.#.#.#
		byte	%00001010	' .#.#....
		byte	%11111110	' .#######
		byte	%10000000	' .......#
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%01010100	' ..#.#.#.
		byte	%10010010	' .#..#..#
		byte	%00000100	' ..#.....
		byte	%10101010	' .#.#.#.#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%10001010	' .#.#...#
		byte	%01000100	' ..#...#.
		byte	%10000000	' .......#
		byte	%00101000	' ...#.#..
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%10010000	' ....#..#
		byte	%00001000	' ...#....
		byte	%10010100	' ..#.#..#
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00100000	' .....#..
		byte	%01010100	' ..#.#.#.
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%10001010	' .#.#...#
		byte	%00010000	' ....#...
		byte	%00000100	' ..#.....
		byte	%10000000	' .......#
		byte	%01000010	' .#....#.
		byte	%10000000	' .......#
		byte	%10000010	' .#.....#
		byte	%00001000	' ...#....
		byte	%10000010	' .#.....#
		byte	%10000000	' .......#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%01111100	' ..#####.
		byte	%01000000	' ......#.
		byte	%00010000	' ....#...
		byte	%01111010	' .#.####.
		byte	%10000010	' .#.....#
		byte	%10000100	' ..#....#
		byte	%00000010	' .#......
		byte	%10000100	' ..#....#
		byte	%00000010	' .#......
		byte	%00000010	' .#......
		byte	%11110010	' .#..####
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00010110	' .##.#...
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%11000010	' .#....##
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%10010010	' .#..#..#
		byte	%00010010	' .#..#...
		byte	%10000000	' .......#
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%00101000	' ...#.#..
		byte	%10010010	' .#..#..#
		byte	%00101000	' ...#.#..
		byte	%00010000	' ....#...
		byte	%00001000	' ...#....
		byte	%00000100	' ..#.....
		byte	%00100000	' .....#..
		byte	%00100000	' .....#..
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01111100	' ..#####.
		byte	%01000010	' .#....#.
		byte	%00000010	' .#......
		byte	%01000010	' .#....#.
		byte	%01111110	' .######.
		byte	%00001000	' ...#....
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%00010000	' ....#...
		byte	%01000000	' ......#.
		byte	%00001010	' .#.#....
		byte	%00010000	' ....#...
		byte	%10010010	' .#..#..#
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%00000010	' .#......
		byte	%00001100	' ..##....
		byte	%00001000	' ...#....
		byte	%01000010	' .#....#.
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%00011000	' ...##...
		byte	%01000010	' .#....#.
		byte	%00010000	' ....#...
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%01001000	' ...#..#.
		byte	%01010101	' #.#.#.#.
		byte	%00110011	' ##..##..
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%11111000	' ...#####
		byte	%00011111	' #####...
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%00000100	' ..#.....
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11101110	' .###.###
		byte	%00000000	' ........
		byte	%11100110	' .##..###
		byte	%11001110	' .###..##
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00101000	' ...#.#..
		byte	%01001001	' #..#..#.
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%01100000	' .....##.
		byte	%01000000	' ......#.
		byte	%01010010	' .#..#.#.
		byte	%01111000	' ...####.
		byte	%10000010	' .#.....#
		byte	%01110000	' ....###.
		byte	%01000100	' ..#...#.
		byte	%00101000	' ...#.#..
		byte	%01000100	' ..#...#.
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%01100000	' .....##.
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%01001000	' ...#..#.
		byte	%00010010	' .#..#...
		byte	%00100100	' ..#..#..
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00111100	' ..####..
		byte	%00111100	' ..####..
		byte	%11111111	' ########
		byte	%10000010	' .#.....#
		byte	%11111110	' .#######
		byte	%10000001	' #......#
		byte	%10111101	' #.####.#
		byte	%00101010	' .#.#.#..
		byte	%00011100	' ..###...
		byte	%00111110	' .#####..
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 6
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%10000000	' .......#
		byte	%00010000	' ....#...
		byte	%11000110	' .##...##
		byte	%00000110	' .##.....
		byte	%00101000	' ...#.#..
		byte	%10000000	' .......#
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%00111000	' ...###..
		byte	%01010100	' ..#.#.#.
		byte	%00001000	' ...#....
		byte	%11000110	' .##...##
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%00000110	' .##.....
		byte	%01000100	' ..#...#.
		byte	%10000000	' .......#
		byte	%01000100	' ..#...#.
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%10010000	' ....#..#
		byte	%01000100	' ..#...#.
		byte	%01100010	' .#...##.
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00100000	' .....#..
		byte	%10010010	' .#..#..#
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%10000110	' .##....#
		byte	%00010000	' ....#...
		byte	%00000010	' .#......
		byte	%10000000	' .......#
		byte	%11111110	' .#######
		byte	%10000000	' .......#
		byte	%10000010	' .#.....#
		byte	%00001000	' ...#....
		byte	%10000010	' .#.....#
		byte	%10000000	' .......#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%00010000	' ....#...
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%10000100	' ..#....#
		byte	%00000010	' .#......
		byte	%10000100	' ..#....#
		byte	%00000010	' .#......
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00100010	' .#...#..
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%10100010	' .#...#.#
		byte	%00100010	' .#...#..
		byte	%10000000	' .......#
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%00101000	' ...#.#..
		byte	%10101010	' .#.#.#.#
		byte	%01000100	' ..#...#.
		byte	%00010000	' ....#...
		byte	%00000100	' ..#.....
		byte	%00000100	' ..#.....
		byte	%01000000	' ......#.
		byte	%00100000	' .....#..
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%00000010	' .#......
		byte	%01000010	' .#....#.
		byte	%00000010	' .#......
		byte	%00001000	' ...#....
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%00010000	' ....#...
		byte	%01000000	' ......#.
		byte	%00010110	' .##.#...
		byte	%00010000	' ....#...
		byte	%10010010	' .#..#..#
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%00000010	' .#......
		byte	%00110000	' ....##..
		byte	%00001000	' ...#....
		byte	%01000010	' .#....#.
		byte	%01000100	' ..#...#.
		byte	%10010010	' .#..#..#
		byte	%00011000	' ...##...
		byte	%01000010	' .#....#.
		byte	%00001000	' ...#....
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%00100100	' ..#..#..
		byte	%10101010	' .#.#.#.#
		byte	%00110011	' ##..##..
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%11111000	' ...#####
		byte	%00011111	' #####...
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%00000010	' .#......
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11101110	' .###.###
		byte	%11111111	' ########
		byte	%11110010	' .#..####
		byte	%10011110	' .####..#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%11111110	' .#######
		byte	%00110110	' .##.##..
		byte	%00000000	' ........
		byte	%01100000	' .....##.
		byte	%10010000	' ....#..#
		byte	%01100000	' .....##.
		byte	%00100010	' .#...#..
		byte	%10001000	' ...#...#
		byte	%01000100	' ..#...#.
		byte	%01001000	' ...#..#.
		byte	%01000100	' ..#...#.
		byte	%00101000	' ...#.#..
		byte	%01000100	' ..#...#.
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00100100	' ..#..#..
		byte	%00100100	' ..#..#..
		byte	%00101010	' .#.#.#..
		byte	%00000000	' ........
		byte	%01111100	' ..#####.
		byte	%01111110	' .######.
		byte	%01111110	' .######.
		byte	%10101101	' #.##.#.#
		byte	%10000010	' .#.....#
		byte	%11111110	' .#######
		byte	%10000001	' #......#
		byte	%10111101	' #.####.#
		byte	%00001000	' ...#....
		byte	%00011100	' ..###...
		byte	%00011100	' ..###...
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 7
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00010000	' ....#...
		byte	%10000000	' .......#
		byte	%00100000	' .....#..
		byte	%10000010	' .#.....#
		byte	%00000010	' .#......
		byte	%00101000	' ...#.#..
		byte	%10000000	' .......#
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00111000	' ...###..
		byte	%00010000	' ....#...
		byte	%01000100	' ..#...#.
		byte	%01000100	' ..#...#.
		byte	%10000010	' .#.....#
		byte	%01000100	' ..#...#.
		byte	%01010100	' ..#.#.#.
		byte	%01010100	' ..#.#.#.
		byte	%01000100	' ..#...#.
		byte	%00000010	' .#......
		byte	%01000100	' ..#...#.
		byte	%10000000	' .......#
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%01000100	' ..#...#.
		byte	%10000010	' .#.....#
		byte	%10010010	' .#..#..#
		byte	%10010010	' .#..#..#
		byte	%10000010	' .#.....#
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%10000100	' ..#....#
		byte	%01111110	' .######.
		byte	%10100010	' .#...#.#
		byte	%01100010	' .#...##.
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00011000	' ...##...
		byte	%00000000	' ........
		byte	%00011000	' ...##...
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%01000000	' ......#.
		byte	%01000010	' .#....#.
		byte	%10000010	' .#.....#
		byte	%00001000	' ...#....
		byte	%10000010	' .#.....#
		byte	%01000000	' ......#.
		byte	%00011000	' ...##...
		byte	%00011000	' ...##...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%10000010	' .#.....#
		byte	%10000100	' ..#....#
		byte	%10000100	' ..#....#
		byte	%01000100	' ..#...#.
		byte	%00000010	' .#......
		byte	%00000010	' .#......
		byte	%10000100	' ..#....#
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00100010	' .#...#..
		byte	%01000010	' .#....#.
		byte	%00000010	' .#......
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%01000100	' ..#...#.
		byte	%00000010	' .#......
		byte	%01000100	' ..#...#.
		byte	%01000010	' .#....#.
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%11000110	' .##...##
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%00000010	' .#......
		byte	%00000100	' ..#.....
		byte	%10000000	' .......#
		byte	%00100000	' .....#..
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000010	' .#....#.
		byte	%01000110	' .##...#.
		byte	%01000010	' .#....#.
		byte	%01100010	' .#...##.
		byte	%00000010	' .#......
		byte	%00001000	' ...#....
		byte	%01100010	' .#...##.
		byte	%01000010	' .#....#.
		byte	%00010000	' ....#...
		byte	%01000000	' ......#.
		byte	%00100010	' .#...#..
		byte	%00010000	' ....#...
		byte	%10010010	' .#..#..#
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%01000110	' .##...#.
		byte	%01100010	' .#...##.
		byte	%00000010	' .#......
		byte	%01000010	' .#....#.
		byte	%01001000	' ...#..#.
		byte	%01100010	' .#...##.
		byte	%00101000	' ...#.#..
		byte	%10010010	' .#..#..#
		byte	%00100100	' ..#..#..
		byte	%01100010	' .#...##.
		byte	%00000100	' ..#.....
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%10010010	' .#..#..#
		byte	%01010101	' #.#.#.#.
		byte	%11001100	' ..##..##
		byte	%00010000	' ....#...
		byte	%00001000	' ...#....
		byte	%11110000	' ....####
		byte	%00001111	' ####....
		byte	%00011111	' #####...
		byte	%11111000	' ...#####
		byte	%00000001	' #.......
		byte	%10000000	' .......#
		byte	%00000011	' ##......
		byte	%11000000	' ......##
		byte	%11101110	' .###.###
		byte	%11111111	' ########
		byte	%11111000	' ...#####
		byte	%00111110	' .#####..
		byte	%11110000	' ....####
		byte	%00011111	' #####...
		byte	%11110000	' ....####
		byte	%00011111	' #####...
		byte	%00010000	' ....#...
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%00011111	' #####...
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00011111	' #####...
		byte	%11110000	' ....####
		byte	%00000000	' ........
		byte	%00101000	' ...#.#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01010000	' ....#.#.
		byte	%01000000	' ......#.
		byte	%01010000	' ....#.#.
		byte	%01010010	' .#..#.#.
		byte	%10001000	' ...#...#
		byte	%00101000	' ...#.#..
		byte	%01001000	' ...#..#.
		byte	%01000100	' ..#...#.
		byte	%00101000	' ...#.#..
		byte	%10000010	' .#.....#
		byte	%00000100	' ..#.....
		byte	%11111110	' .#######
		byte	%00001100	' ..##....
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010010	' .#..#...
		byte	%01001000	' ...#..#.
		byte	%00110000	' ....##..
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%10111101	' #.####.#
		byte	%10111101	' #.####.#
		byte	%10110101	' #.#.##.#
		byte	%10000010	' .#.....#
		byte	%11111110	' .#######
		byte	%11000011	' ##....##
		byte	%11000011	' ##....##
		byte	%00001000	' ...#....
		byte	%00001000	' ...#....
		byte	%00011100	' ..###...
		byte	%00111110	' .#####..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 8
		byte	%11111110	' .#######
		byte	%00000010	' .#......
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%01000000	' ......#.
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%11101110	' .###.###
		byte	%10000000	' .......#
		byte	%00000000	' ........
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00111000	' ...###..
		byte	%00111000	' ...###..
		byte	%11111110	' .#######
		byte	%00111000	' ...###..
		byte	%00111000	' ...###..
		byte	%00111000	' ...###..
		byte	%00111000	' ...###..
		byte	%00000000	' ........
		byte	%11000110	' .##...##
		byte	%10000000	' .......#
		byte	%11111110	' .#######
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00111000	' ...###..
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%01111110	' .######.
		byte	%00010000	' ....#...
		byte	%01000000	' ......#.
		byte	%10011100	' ..###..#
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00011000	' ...##...
		byte	%00000000	' ........
		byte	%00011000	' ...##...
		byte	%00000000	' ........
		byte	%01111100	' ..#####.
		byte	%01111100	' ..#####.
		byte	%11111110	' .#######
		byte	%01111100	' ..#####.
		byte	%01000000	' ......#.
		byte	%00111100	' ..####..
		byte	%01111100	' ..#####.
		byte	%00001000	' ...#....
		byte	%01111100	' ..#####.
		byte	%00111100	' ..####..
		byte	%00011000	' ...##...
		byte	%00011000	' ...##...
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%01111000	' ...####.
		byte	%10000010	' .#.....#
		byte	%01111110	' .######.
		byte	%01111000	' ...####.
		byte	%00111110	' .#####..
		byte	%11111110	' .#######
		byte	%00000010	' .#......
		byte	%01111000	' ...####.
		byte	%10000010	' .#.....#
		byte	%01111100	' ..#####.
		byte	%00011100	' ..###...
		byte	%10000010	' .#.....#
		byte	%11111110	' .#######
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00111000	' ...###..
		byte	%00000010	' .#......
		byte	%10111000	' ...###.#
		byte	%10000010	' .#.....#
		byte	%01111100	' ..#####.
		byte	%00010000	' ....#...
		byte	%01111100	' ..#####.
		byte	%00010000	' ....#...
		byte	%10000010	' .#.....#
		byte	%10000010	' .#.....#
		byte	%00010000	' ....#...
		byte	%11111110	' .#######
		byte	%00111100	' ..####..
		byte	%00000000	' ........
		byte	%00111100	' ..####..
		byte	%00000000	' ........
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%10111100	' ..####.#
		byte	%00111010	' .#.###..
		byte	%00111100	' ..####..
		byte	%01011100	' ..###.#.
		byte	%00111100	' ..####..
		byte	%00001000	' ...#....
		byte	%01011100	' ..###.#.
		byte	%01000010	' .#....#.
		byte	%00111000	' ...###..
		byte	%01000000	' ......#.
		byte	%01000010	' .#....#.
		byte	%00111000	' ...###..
		byte	%10010010	' .#..#..#
		byte	%01000010	' .#....#.
		byte	%00111100	' ..####..
		byte	%00111010	' .#.###..
		byte	%01011100	' ..###.#.
		byte	%00000010	' .#......
		byte	%00111100	' ..####..
		byte	%00110000	' ....##..
		byte	%01011100	' ..###.#.
		byte	%00010000	' ....#...
		byte	%01101100	' ..##.##.
		byte	%01000010	' .#....#.
		byte	%01011100	' ..###.#.
		byte	%01111110	' .######.
		byte	%00110000	' ....##..
		byte	%00000000	' ........
		byte	%00011000	' ...##...
		byte	%00000000	' ........
		byte	%01001000	' ...#..#.
		byte	%10101010	' .#.#.#.#
		byte	%11001100	' ..##..##
		byte	%00010000	' ....#...
		byte	%00001000	' ...#....
		byte	%11110000	' ....####
		byte	%00001111	' ####....
		byte	%00011111	' #####...
		byte	%11111000	' ...#####
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00100000	' .....#..
		byte	%11101110	' .###.###
		byte	%11111111	' ########
		byte	%11111100	' ..######
		byte	%01111110	' .######.
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00101000	' ...#.#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11111000	' ...#####
		byte	%00100000	' .....#..
		byte	%11111000	' ...#####
		byte	%10001100	' ..##...#
		byte	%01111000	' ...####.
		byte	%00010000	' ....#...
		byte	%00110000	' ....##..
		byte	%10111100	' ..####.#
		byte	%00101000	' ...#.#..
		byte	%11111110	' .#######
		byte	%11111110	' .#######
		byte	%00000100	' ..#.....
		byte	%10010010	' .#..#..#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00100000	' .....#..
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%10111101	' #.####.#
		byte	%10111101	' #.####.#
		byte	%10101101	' #.##.#.#
		byte	%01111100	' ..#####.
		byte	%01111100	' ..#####.
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00111110	' .#####..
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 9
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01010101	' #.#.#.#.
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%00000100	' ..#.....
		byte	%11100000	' .....###
		byte	%00000111	' ###.....
		byte	%00111111	' ######..
		byte	%11111100	' ..######
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00101000	' ...#.#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%11110000	' ....####
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00101000	' ...#.#..
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%01100000	' .....##.
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%10111101	' #.####.#
		byte	%10111101	' #.####.#
		byte	%10110101	' #.#.##.#
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 10
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000010	' .#....#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000100	' ..#...#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000010	' .#....#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%10101010	' .#.#.#.#
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%00000100	' ..#.....
		byte	%11100000	' .....###
		byte	%00000111	' ###.....
		byte	%00111111	' ######..
		byte	%11111100	' ..######
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00001000	' ...#....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00101000	' ...#.#..
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00111100	' ..####..
		byte	%00111100	' ..####..
		byte	%00111100	' ..####..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 11
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00111100	' ..####..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00111000	' ...###..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000010	' .#......
		byte	%01000000	' ......#.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00111100	' ..####..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01010101	' #.#.#.#.
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000010	' .#......
		byte	%11000000	' ......##
		byte	%00000011	' ##......
		byte	%01111111	' #######.
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00100000	' .....#..
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001000	' ...#....
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010100	' ..#.#...
		byte	%00101000	' ...#.#..
		byte	%00100100	' ..#..#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 12
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%10101010	' .#.#.#.#
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000010	' .#......
		byte	%11000000	' ......##
		byte	%00000011	' ##......
		byte	%01111111	' #######.
		byte	%11111110	' .#######
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000000	' ......#.
		byte	%00000010	' .#......
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000100	' ..#.....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00100010	' .#...#..
		byte	%01000100	' ..#...#.
		byte	%00100100	' ..#..#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 13
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01010101	' #.#.#.#.
		byte	%00000000	' ........
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%00100100	' ..#..#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 14
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%10101010	' .#.#.#.#
		byte	%00000000	' ........
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01000010	' .#....#.
		byte	%01000010	' .#....#.
		byte	%00100100	' ..#..#..
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########

				' scanrow 15
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01010101	' #.#.#.#.
		byte	%00000000	' ........
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%10000000	' .......#
		byte	%00000001	' #.......
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00010000	' ....#...
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%01100011	' ##...##.
		byte	%11000110	' .##...##
		byte	%01100110	' .##..##.
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00000000	' ........
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%00001111	' ####....
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11110000	' ....####
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
		byte	%11111111	' ########
{{
+------------------------------------------------------------------------------------------------------------------------------+
|				    TERMS OF USE: Parallax Object Exchange License					       |
+------------------------------------------------------------------------------------------------------------------------------+
|Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation    | |files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    |
|modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software|
|is furnished to do so, subject to the following conditions:                                                                   |
|                                                                                                                              |
|The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.|
|                                                                                                                              |
|THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE	       |
|WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         |
|COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   |
|ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                         |
+------------------------------------------------------------------------------------------------------------------------------+
}}
